- Added an option to disable the TextCollection.
[SXSI/XMLTree.git] / XMLTree.h
index e8cc76a..c054b01 100644 (file)
--- a/XMLTree.h
+++ b/XMLTree.h
@@ -90,6 +90,8 @@ class XMLTree {
    int parArraySize;\r
    int ntagnames;\r
    unsigned int *empty_texts_aux;\r
+   bool found_attributes;\r
+   bool disable_tc;\r
    \r
 public:\r
 \r
@@ -209,14 +211,16 @@ public:
    /** ParentNode(d): returns the parent node of document identifier d. */\r
    treeNode ParentNode(DocID d);\r
 \r
-   /** OpenDocument(empty_texts,sample_rate_text): initilizes the construction\r
+   /** OpenDocument(empty_texts,sample_rate_text,dtc): initilizes the construction\r
     * of the data structure for the XML document. Parameter empty_texts \r
     * indicates whether we index empty texts in document or not. Parameter \r
     * sample_rate_text indicates the sampling rate for the text searching data\r
     * structures (small values get faster searching but a bigger space \r
* requirement). Returns a non-zero value upon success, NULLT in case of \r
     * error. */\r
-   int OpenDocument(bool empty_texts, int sample_rate_text);\r
+   int OpenDocument(bool empty_texts, int sample_rate_text, bool dtc);\r
 \r
    /** CloseDocument(): finishes the construction of the data structure for \r
     * the XML document. Tree and tags are represented in the final form, \r
@@ -254,7 +258,9 @@ public:
     * Returns NULL in case that the tag identifier is not valid.*/\r
    unsigned char *GetTagName(TagType tagid);\r
 \r
-   /** Prefix(s): search for texts prefixed by string s. */\r
+\r
+   TagType RegisterTag(unsigned char *tagname);\r
+\r
    bool EmptyText(DocID i) {\r
       return Text->EmptyText(i);\r
    }\r
@@ -209,14 +211,16 @@ public:
     * sample_rate_text indicates the sampling rate for the text searching data\r
     * structures (small values get faster searching but a bigger space \r
-    * requirement). Returns a non-zero value upon success, NULLT in case of \r
+    * requirement). dtc disable the use of the TextCollection\r
+    * (i.e. everything is considered an empty text *)\r
+    * Returns a non-zero value upon success, NULLT in case of \r
     * error. */\r